.md-edit .preview {
	height: 400px;
	overflow: auto;
}

.md-edit textarea {
	height: 400px;
	resize: none;
	font-family: "Courier New", Courier, "Lucida Sans Typewriter", "Lucida Typewriter", monospace;
	font-weight: bold;
}

.md-edit .preview img {
	max-width: 100%;
	height: auto;
	border-radius: 4px;
}

.markdown-library-chooser {
	height: 325px;
	overflow: auto;
	padding: 20px;
	border-top: 1px solid #ccc;
	border-bottom: 1px solid #ccc;
	background: #eee;
	margin: 20px 0;
}

.markdown-library-chooser a {
	display: inline-block;
	margin-bottom: 5px;
}

.markdown-library-chooser .selected img {
	background-color: #66afe9;
}